from . import WORKLOAD_CONTAINERS


def efa(modified_spec: dict, config: dict):
    spec = modified_spec["request"]["object"]["spec"]
    if "volumes" not in spec:
        spec["volumes"] = []

    hugepage = config["hugepage"]
    n = config["numAdapters"]

    volumes = spec["volumes"]
    should_add = True
    for volume in volumes:
        if volume["name"] == "efa0":
            should_add = False

    if should_add:
        spec["volumes"].extend(
            [
                {
                    "name": f"efa{i}",
                    "hostPath": {
                        "path": f"/dev/infiniband/uverbs{i}",
                    },
                }
                for i in range(n)
            ]
        )

    # Set Priviledged
    for container in spec["containers"]:
        name = container["name"]
        if name in WORKLOAD_CONTAINERS:
            if "volumeMounts" not in container:
                container["volumeMounts"] = []

            should_add = True
            for mount in container["volumeMounts"]:
                if mount["name"] == "efa0":
                    should_add = False

            if should_add:
                container["volumeMounts"].extend(
                    [
                        {
                            "name": f"efa{i}",
                            "mountPath": f"/dev/infiniband/uverbs{i}",
                        }
                        for i in range(n)
                    ]
                )

            # Upsert Security Context
            container["securityContext"] = container.get("securityContext", {})
            container["securityContext"]["privileged"] = True

            # Request HugePages
            container["resources"]["limits"]["hugepages-2Mi"] = hugepage
