import logging
from pprint import pformat

logger = logging.getLogger(__name__)


def insert_container(modified_spec: dict, config: dict):
    container_type = config["containerType"]
    if container_type == "app":
        spec_key = "containers"
    elif container_type == "init":
        spec_key = "initContainers"
    else:
        logger.warn(f"Unknown container type: {container_type}")
        return

    if container_name := config["spec"].get("name"):
        spec = modified_spec["request"]["object"]["spec"]
        spec[spec_key] = spec.get(spec_key, [])
        for container in spec[spec_key]:
            if container["name"] == container_name:
                logger.warn(f"Container {container_name} already exists.")
                return

        logger.debug(f'Inserting: {pformat(config["spec"])}')
        spec[spec_key].append(config["spec"])
    else:
        logger.warn("Container had no name.")
    logger.debug(f"Final spec: {pformat(spec)}")
